@@ -19,10 +19,8 @@
 #' # Arrange in decreasing order
 #' data_arrange(head(mtcars), "-carb")
 #'
-#' \dontrun{
 #' # Throw an error if one of the variables specified doesn't exist
-#' data_arrange(head(mtcars), c("gear", "foo"), safe = FALSE)
-#' }
+#' try(data_arrange(head(mtcars), c("gear", "foo"), safe = FALSE))
 #' @export
 data_arrange <- function(data, select = NULL, safe = TRUE) {
   UseMethod("data_arrange")
@@ -48,8 +46,8 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
   dont_exist <- select[which(!select %in% names(data))]
 
   if (length(dont_exist) > 0) {
-    if (!safe) {
-      insight::format_error(
+    if (safe) {
+      insight::format_warning(
         paste0(
           "The following column(s) don't exist in the dataset: ",
           text_concatenate(dont_exist), "."
@@ -57,7 +55,7 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
         .misspelled_string(names(data), dont_exist, "Possibly misspelled?")
       )
     } else {
-      insight::format_warning(
+      insight::format_error(
         paste0(
           "The following column(s) don't exist in the dataset: ",
           text_concatenate(dont_exist), "."
@@ -72,7 +70,7 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
     return(data)
   }
 
-  already_sorted <- all(vapply(data[, select, drop = FALSE], .is_sorted, logical(1)))
+  already_sorted <- all(vapply(data[, select, drop = FALSE], .is_sorted, logical(1L)))
 
   if (isTRUE(already_sorted)) {
     return(data)
