@@ -11,7 +11,7 @@
 #' levels after `x` was converted to factor. Else, factor levels are based on
 #' the values of `x` (i.e. as if using `as.factor()`).
 #' @param ... Arguments passed to or from other methods.
-#' @inheritParams find_columns
+#' @inheritParams extract_column_names
 #' @inheritParams categorize
 #'
 #' @inheritSection center Selection of variables - the `select` argument
@@ -79,6 +79,12 @@ to_factor.character <- to_factor.numeric
 #' @export
 to_factor.Date <- to_factor.numeric
 
+#' @export
+to_factor.haven_labelled <- to_factor.numeric
+
+#' @export
+to_factor.double <- to_factor.numeric
+
 #' @rdname to_factor
 #' @export
 to_factor.data.frame <- function(x,
@@ -89,7 +95,7 @@ to_factor.data.frame <- function(x,
                                  regex = FALSE,
                                  verbose = TRUE,
                                  ...) {
-  # sanity check, return as is for complete factor
+  # validation check, return as is for complete factor
   if (all(vapply(x, is.factor, FUN.VALUE = logical(1L)))) {
     return(x)
   }
